@@ -19,7 +19,7 @@ class instrument(object):
     __LogFile = None
     __LogReadings = True
     # It's recommended to use a power of 2 for BufferSize
-    __InBufferSize = 4* 2**10   #4kByte
+    _InBufferSize = 4* 2**10   #4kByte
     __IDString = ""
     __Options = None
     
@@ -241,7 +241,7 @@ class instrument(object):
             raise Exception("Connection is closed, use connect first!")
 
         if NumberOfBytes == -1:
-            NumberOfBytes = self.__InBufferSize
+            NumberOfBytes = self._InBufferSize
         
         data = self.__msocket.recv(NumberOfBytes)
         
